@@ -15,7 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 
-// $Id: dictionarycreationwizard.h 779869 2008-02-27 08:28:05Z mlaurent $
+// $Id: dictionarycreationwizard.h 1178876 2010-09-24 07:47:31Z mlaurent $
 
 #ifndef DICTIONARYCREATIONWIZARD_H
 #define DICTIONARYCREATIONWIZARD_H
@@ -23,8 +23,10 @@
 #include <QtCore/QList>
 #include <QtCore/QMap>
 #include <Qt3Support/Q3Dict>
+#include <Q3ScrollView>
 
 #include <k3wizard.h>
+#include <kcombobox.h>
 #include <knuminput.h>
 
 #include "ui_creationsourceui.h"
@@ -33,7 +35,7 @@
 
 class CompletionWizardWidget;
 class QTextCodec;
-class QComboBox;
+class KComboBox;
 class MergeWidget;
 
 class CreationSourceDetailsWidget : public QWidget, public Ui::CreationSourceDetailsUI {
@@ -42,7 +44,7 @@ public:
    CreationSourceDetailsWidget(QWidget *parent, const char *name)
       : QWidget(parent) {
       setupUi(this);
-      setObjectName(name);
+      setObjectName( QLatin1String( name ) );
    }
 };
 
@@ -52,7 +54,7 @@ public:
    CreationSourceWidget(QWidget *parent, const char *name)
       : QWidget(parent) {
       setupUi(this);
-      setObjectName(name);
+      setObjectName(QLatin1String( name ));
    }
 };
 
@@ -62,11 +64,11 @@ public:
    KDEDocSourceWidget(QWidget *parent, const char *name)
       : QWidget(parent) {
       setupUi(this);
-      setObjectName(name);
+      setObjectName( QLatin1String( name ) );
       languageButton->showLanguageCodes(true);
       languageButton->loadAllLanguages();
 
-      ooDictURL->setFilter ("*.dic");
+      ooDictURL->setFilter (QLatin1String( "*.dic" ));
    }
 };
 
@@ -79,9 +81,9 @@ class DictionaryCreationWizard : public K3Wizard {
    Q_OBJECT
 public:
    DictionaryCreationWizard (QWidget *parent, const char *name,
-                             QStringList dictionaryNames,
-                             QStringList dictionaryFiles,
-                             QStringList dictionaryLanguages);
+                             const QStringList &dictionaryNames,
+                             const QStringList &dictionaryFiles,
+                             const QStringList &dictionaryLanguages);
    ~DictionaryCreationWizard();
 
    QString createDictionary();
@@ -93,7 +95,7 @@ private slots:
 
 private:
    void buildCodecList ();
-   void buildCodecCombo (QComboBox *combo);
+   void buildCodecCombo (KComboBox *combo);
 
    CreationSourceWidget *creationSource;
    CreationSourceDetailsWidget *fileWidget;
@@ -113,9 +115,9 @@ class MergeWidget : public Q3ScrollView {
    Q_OBJECT
 public:
    MergeWidget(K3Wizard *parent, const char *name,
-               QStringList dictionaryNames,
-               QStringList dictionaryFiles,
-               QStringList dictionaryLanguages);
+               const QStringList &dictionaryNames,
+               const QStringList &dictionaryFiles,
+               const QStringList &dictionaryLanguages);
    ~MergeWidget();
 
    QMap <QString, int> mergeParameters ();
